@@ -1,19 +1,33 @@
+// SPDX-FileCopyrightText: 2023 ~ 2025 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include <dfm-extension/dfm-extension.h>
 
 #include "mymenuplugin.h"
 #include "myemblemiconplugin.h"
-#include "mywindowplugin.h"
+#ifdef DFMEXT_INTERFACE_Window
+#    include "mywindowplugin.h"
+#endif
+#ifdef DFMEXT_INTERFACE_File
+#    include "myfileplugin.h"
+#endif
 
 // 右键菜单的扩展
 static DFMEXT::DFMExtMenuPlugin *myMenu { nullptr };
 // 角标的扩展
 static DFMEXT::DFMExtEmblemIconPlugin *myEmblemIcon { nullptr };
 
-#ifdef DFMEXT_INTERFACE_Window
 // 窗口的扩展
+#ifdef DFMEXT_INTERFACE_Window
 static DFMEXT::DFMExtWindowPlugin *myWindow { nullptr };
 #endif
 
+// 本地文件操作的扩展
+#ifdef DFMEXT_INTERFACE_File
+static DFMEXT::DFMExtFilePlugin *myFile { nullptr };
+#endif
+
 extern "C" void dfm_extension_initiliaze()
 {
     myMenu = new Exapmle::MyMenuPlugin;
@@ -21,6 +35,10 @@ extern "C" void dfm_extension_initiliaze()
 #ifdef DFMEXT_INTERFACE_Window
     myWindow = new Exapmle::MyWindowPlugin;
 #endif
+
+#ifdef DFMEXT_INTERFACE_File
+    myFile = new Exapmle::MyFilePlugin;
+#endif
 }
 
 extern "C" void dfm_extension_shutdown()
@@ -30,6 +48,10 @@ extern "C" void dfm_extension_shutdown()
 #ifdef DFMEXT_INTERFACE_Window
     delete myWindow;
 #endif
+
+#ifdef DFMEXT_INTERFACE_File
+    delete myFile;
+#endif
 }
 
 extern "C" DFMEXT::DFMExtMenuPlugin *dfm_extension_menu()
@@ -48,3 +70,10 @@ extern "C" DFMEXT::DFMExtWindowPlugin *dfm_extension_window()
     return myWindow;
 }
 #endif
+
+#ifdef DFMEXT_INTERFACE_File
+extern "C" DFMEXT::DFMExtFilePlugin *dfm_extension_file()
+{
+    return myFile;
+}
+#endif
