@@ -21,6 +21,8 @@ Q_LOGGING_CATEGORY(logAppDialog, "org.deepin.dde.filemanager.filedialog")
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 DFMBASE_USE_NAMESPACE
+using namespace GlobalDConfDefines::ConfigPath;
+using namespace GlobalDConfDefines::BaseConfig;
 
 #ifdef DFM_ORGANIZATION_NAME
 #    define ORGANIZATION_NAME DFM_ORGANIZATION_NAME
@@ -32,10 +34,10 @@ static constexpr char kDialogPluginInterface[] { "org.deepin.plugin.filedialog"
 static constexpr char kFmPluginInterface[] { "org.deepin.plugin.filemanager" };
 static constexpr char kCommonPluginInterface[] { "org.deepin.plugin.common" };
 
-static constexpr char kDialogCorePluginName[] { "filedialogplugin-core" };
-static constexpr char kDialogCoreLibName[] { "libfiledialogplugin-core.so" };
+static constexpr char kDialogCorePluginName[] { "filedialog-core-plugin" };
+static constexpr char kDialogCoreLibName[] { "libfiledialog-core-plugin.so" };
 static constexpr char kDFMCorePluginName[] { "dfmplugin-core" };
-static constexpr char kDFMCoreLibName[] { "libdfmplugin-core.so" };
+static constexpr char kDFMCoreLibName[] { "libdfm-core-plugin.so" };
 
 static void initLogFilter()
 {
@@ -135,6 +137,7 @@ static bool pluginsLoad()
                                          pluginsDirs);
     DPF_NAMESPACE::LifeCycle::setLazyloadFilter(lazyLoadFilter);
     DPF_NAMESPACE::LifeCycle::setBlackListFilter(blackListFilter);
+    DPF_NAMESPACE::LifeCycle::registerQtVersionInsensitivePlugins(Plugins::Utils::filemanagerAllPlugins());
 
     qCInfo(logAppDialog) << "Depend library paths:" << DApplication::libraryPaths();
     qCInfo(logAppDialog) << "Load plugin paths: " << dpf::LifeCycle::pluginPaths();
@@ -181,7 +184,6 @@ int main(int argc, char *argv[])
     initLogSetting();
 
     a.setOrganizationName(ORGANIZATION_NAME);
-    a.setAttribute(Qt::AA_UseHighDpiPixmaps);
     a.setQuitOnLastWindowClosed(false);
     a.setWindowIcon(QIcon::fromTheme("dde-file-manager"));
 
@@ -199,12 +201,11 @@ int main(int argc, char *argv[])
 
     if (!pluginsLoad()) {
         qCCritical(logAppDialog) << "Load pugin failed!";
-        abort();
+        Q_ASSERT_X(false, "pluginsLoad", "Failed to load plugins");
     }
 
     int ret { a.exec() };
     DPF_NAMESPACE::LifeCycle::shutdownPlugins();
-    qWarning() << "Main thread quit";
     if (qApp->property("SIGTERM").toBool()) {
         qWarning() << "Exit app by SIGTERM, reuturn: " << ret;
         _Exit(ret);
