@@ -21,10 +21,12 @@
 Q_LOGGING_CATEGORY(logAppDaemon, "org.deepin.dde.Filemanager.Daemon")
 
 static constexpr char kDaemonInterface[] { "org.deepin.plugin.daemon" };
-static constexpr char kPluginCore[] { "daemonplugin-core" };
-static constexpr char kLibCore[] { "libdaemonplugin-core.so" };
+static constexpr char kPluginCore[] { "dfmdaemon-core-plugin" };
+static constexpr char kLibCore[] { "libdfmdaemon-core-plugin.so" };
 
 DFMBASE_USE_NAMESPACE
+using namespace GlobalDConfDefines::ConfigPath;
+using namespace GlobalDConfDefines::BaseConfig;
 
 #ifdef DFM_ORGANIZATION_NAME
 #    define ORGANIZATION_NAME DFM_ORGANIZATION_NAME
@@ -64,7 +66,7 @@ static bool pluginsLoad()
                 << QString(DFM_PLUGIN_DAEMON_EDGE_DIR);
 #endif
     qCInfo(logAppDaemon) << "Using plugins dir:" << pluginsDirs;
-    QStringList blackNames { DConfigManager::instance()->value(kPluginsDConfName, "server.blackList").toStringList() };
+    QStringList blackNames { DConfigManager::instance()->value(kPluginsDConfName, "daemon.blackList").toStringList() };
     DPF_NAMESPACE::LifeCycle::initialize({ kDaemonInterface }, pluginsDirs, blackNames);
 
     qCInfo(logAppDaemon) << "Depend library paths:" << QCoreApplication::libraryPaths();
@@ -135,7 +137,7 @@ int main(int argc, char *argv[])
 
     if (!pluginsLoad()) {
         qCCritical(logAppDaemon) << "Load pugin failed!";
-        abort();
+        Q_ASSERT_X(false, "pluginsLoad", "Failed to load plugins");
     }
 
     int ret { a.exec() };
