@@ -5,6 +5,7 @@
 #include "config.h"   //cmake
 #include "singleapplication.h"
 #include "commandparser.h"
+#include "dragmonitor.h"
 
 #include "tools/upgrade/builtininterface.h"
 
@@ -26,18 +27,14 @@
 #include <signal.h>
 #include <malloc.h>
 
-#ifdef DFM_UI_TYPE_QML
-#    include <dfm-gui/sharedqmlengine.h>
-#    include <dfm-gui/windowmanager.h>
-#    include <QQmlEngine>
-#endif
-
 Q_LOGGING_CATEGORY(logAppFileManager, "org.deepin.dde.filemanager.filemanager")
 
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 DCORE_USE_NAMESPACE
 DFMBASE_USE_NAMESPACE
+using namespace GlobalDConfDefines::ConfigPath;
+using namespace GlobalDConfDefines::BaseConfig;
 
 #ifdef DFM_ORGANIZATION_NAME
 #    define ORGANIZATION_NAME DFM_ORGANIZATION_NAME
@@ -51,7 +48,7 @@ DFMBASE_USE_NAMESPACE
 static constexpr char kFmPluginInterface[] { "org.deepin.plugin.filemanager" };
 static constexpr char kCommonPluginInterface[] { "org.deepin.plugin.common" };
 static constexpr char kPluginCore[] { "dfmplugin-core" };
-static constexpr char kLibCore[] { "libdfmplugin-core.so" };
+static constexpr char kLibCore[] { "libdfm-core-plugin.so" };
 
 static constexpr int kMemoryThreshold { 80 * 1024 };   // 80MB
 static constexpr int kTimerInterval { 60 * 1000 };   // 1 min
@@ -110,50 +107,50 @@ static bool lazyLoadFilter(const QString &name)
     return false;
 }
 
-static QStringList buildBlackNames()
+static bool lazyLoadFilterForHeadless(const QString &name)
 {
-    QStringList blackNames { DConfigManager::instance()->value(kPluginsDConfName, "filemanager.blackList").toStringList() };
-    const QStringList &disableNames { DConfigManager::instance()->value(kPluginsDConfName, "filemanager.disablelist").toStringList() };
+    static const auto &kAllNames {
+        DFMBASE_NAMESPACE::Plugins::Utils::filemanagerAllPlugins()
+    };
+
+    if (!kAllNames.contains(name))
+        return true;
+    return false;
+}
+
+static bool blackListFilter(const QString &name)
+{
+    static QStringList blackNames { DConfigManager::instance()->value(kPluginsDConfName, "filemanager.blackList").toStringList() };
+    static bool isAdmin = SysInfoUtils::isOpenAsAdmin();
+    static std::once_flag flag;
+    std::call_once(flag, [] {
 #ifndef ENABLE_SMB_IN_ADMIN
-    /*
-     * NOTE(xust): the secret manager cannot be launched in WAYLAND ADMIN mode,
-     * which cause file-manager freeze when mount samba (dfm-mount using secret-manager
-     * to save/get the password of samba by sync).
-     * and the Admin mode is designed for operate files those normal user cannot write
-     * and should be the smallest dfm, so remove the smb-browser plugin in Admin mode
-     * */
-    if (SysInfoUtils::isOpenAsAdmin() && !blackNames.contains("dfmplugin-smbbrowser"))
-        blackNames << "dfmplugin-smbbrowser";
+        /*
+         * NOTE(xust): the secret manager cannot be launched in WAYLAND ADMIN mode,
+         * which cause file-manager freeze when mount samba (dfm-mount using secret-manager
+         * to save/get the password of samba by sync).
+         * and the Admin mode is designed for operate files those normal user cannot write
+         * and should be the smallest dfm, so remove the smb-browser plugin in Admin mode
+         * */
+        if (isAdmin && !blackNames.contains("dfmplugin-smbbrowser"))
+            blackNames << "dfmplugin-smbbrowser";
 #endif
-
-    std::copy_if(disableNames.begin(), disableNames.end(), std::back_inserter(blackNames), [blackNames](const QString &name) {
-        return !blackNames.contains(name);
+        static QStringList disableNames { DConfigManager::instance()->value(kPluginsDConfName, "filemanager.disablelist").toStringList() };
+        std::copy_if(disableNames.begin(), disableNames.end(), std::back_inserter(blackNames),
+                     [](const QString &name) {
+                         return !blackNames.contains(name);
+                     });
+        qCDebug(logAppFileManager) << "build all blacknames:" << blackNames;
     });
-    qCDebug(logAppFileManager) << "build all blacknames:" << blackNames;
-    return blackNames;
+
+    if (blackNames.contains(name))
+        return true;
+
+    // Disable all third-party plugins when running the file manager as administrator
+    static const QStringList &kAllNames { DFMBASE_NAMESPACE::Plugins::Utils::filemanagerAllPlugins() };
+    return isAdmin && !kAllNames.contains(name);
 }
 
-#ifdef DFM_UI_TYPE_QML
-static bool initQmlEngine()
-{
-    QSharedPointer<QQmlEngine> globalEngine = dfmgui::WindowManager::instance()->engine();
-    if (!globalEngine) {
-        return false;
-    }
-
-#    ifdef QT_DEBUG
-    const QString &pluginsDir { DFM_BUILD_PLUGIN_DIR };
-    globalEngine->addImportPath(pluginsDir + "/qml");
-#    else
-    globalEngine->addImportPath(DFM_QML_MODULE);
-#    endif
-
-    dfmgui::WindowManager::instance()->initialize();
-    return true;
-}
-
-#endif
-
 static bool pluginsLoad()
 {
     QString msg;
@@ -164,11 +161,9 @@ static bool pluginsLoad()
 #ifdef QT_DEBUG
     const QString &pluginsDir { DFM_BUILD_PLUGIN_DIR };
     qCInfo(logAppFileManager) << QString("Load plugins path : %1").arg(pluginsDir);
-    qApp->setProperty("DFM_BUILD_PLUGIN_DIR", pluginsDir);
     pluginsDirs.push_back(pluginsDir + "/filemanager");
     pluginsDirs.push_back(pluginsDir + "/common");
     pluginsDirs.push_back(pluginsDir);
-    qApp->setProperty("DFM_BUILD_PLUGIN_DIR", DFM_BUILD_PLUGIN_DIR);
 #else
     pluginsDirs << QString(DFM_PLUGIN_COMMON_CORE_DIR)
                 << QString(DFM_PLUGIN_FILEMANAGER_CORE_DIR)
@@ -177,15 +172,18 @@ static bool pluginsLoad()
 #endif
 
     qCInfo(logAppFileManager) << "Using plugins dir:" << pluginsDirs;
-    DPF_NAMESPACE::LifeCycle::initialize({ kFmPluginInterface, kCommonPluginInterface }, pluginsDirs, buildBlackNames());
-
+    DPF_NAMESPACE::LifeCycle::initialize({ kFmPluginInterface, kCommonPluginInterface }, pluginsDirs);
+    DPF_NAMESPACE::LifeCycle::setBlackListFilter(blackListFilter);
+    DPF_NAMESPACE::LifeCycle::registerQtVersionInsensitivePlugins(Plugins::Utils::filemanagerAllPlugins());
     // disbale lazy load if enbale headless
     bool enableHeadless { DConfigManager::instance()->value(kDefaultCfgPath, "dfm.headless", false).toBool() };
-    if (enableHeadless && CommandParser::instance().isSet("d"))
+    if (enableHeadless && CommandParser::instance().isSet("d")) {
         qCDebug(logAppFileManager) << "hot launch";
-    else
+        // Non-built-in plugins do not guarantee correctness (e.g. udrive)
+        DPF_NAMESPACE::LifeCycle::setLazyloadFilter(lazyLoadFilterForHeadless);
+    } else {
         DPF_NAMESPACE::LifeCycle::setLazyloadFilter(lazyLoadFilter);
-
+    }
     qCInfo(logAppFileManager) << "Depend library paths:" << DApplication::libraryPaths();
     qCInfo(logAppFileManager) << "Load plugin paths: " << DPF_NAMESPACE::LifeCycle::pluginPaths();
 
@@ -219,7 +217,8 @@ static void handleSIGTERM(int sig)
     if (qApp) {
         // Don't use headless if SIGTERM, cause system shutdown blocked
         qApp->setProperty("SIGTERM", true);
-        qApp->quit();
+        // 重启或关闭系统时，信号处理会阻塞进程
+        QTimer::singleShot(0, qApp, &QApplication::quit);
     }
 }
 
@@ -332,7 +331,6 @@ int main(int argc, char *argv[])
                                                            "featured with searching, copying, "
                                                            "trash, compression/decompression, file property "
                                                            "and other useful functions."));
-    a.setAttribute(Qt::AA_UseHighDpiPixmaps);
     DPF_NAMESPACE::backtrace::installStackTraceHandler();
     autoReleaseMemory();
 
@@ -365,15 +363,9 @@ int main(int argc, char *argv[])
         // check upgrade
         checkUpgrade(&a);
 
-#ifdef DFM_UI_TYPE_QML
-        if (!initQmlEngine()) {
-            qCCritical(logAppFileManager) << "init QQmlEngine failed!";
-            abort();
-        }
-#endif
         if (!pluginsLoad()) {
             qCCritical(logAppFileManager) << "Load pugin failed!";
-            abort();
+            Q_ASSERT_X(false, "pluginsLoad", "Failed to load plugins");
         }
         signal(SIGTERM, handleSIGTERM);
         signal(SIGPIPE, handleSIGPIPE);
@@ -383,14 +375,21 @@ int main(int argc, char *argv[])
         return 0;
     }
 
+    // NOTE: temp code!!!!!!!!!!!
+    QScopedPointer<dfm_drag::DragMoniter> mo(new dfm_drag::DragMoniter);
+    if (!SysInfoUtils::isOpenAsAdmin())
+        mo->registerDBus();
+
     qCWarning(logAppFileManager) << " --- app start --- pid = " << a.applicationPid();
     int ret { a.exec() };
+
+    mo->unRegisterDBus();
+    a.closeServer();
     DPF_NAMESPACE::LifeCycle::shutdownPlugins();
 
     bool enableHeadless { DConfigManager::instance()->value(kDefaultCfgPath, "dfm.headless", false).toBool() };
     bool isSigterm { qApp->property("SIGTERM").toBool() };
     if (!isSigterm && enableHeadless && !SysInfoUtils::isOpenAsAdmin()) {
-        a.closeServer();
         QProcess::startDetached(QString(argv[0]), { "-d" });
     }
 
