@@ -35,6 +35,8 @@
 using namespace dfmbase;
 DFM_MOUNT_USE_NS
 using namespace GlobalServerDefines;
+using namespace GlobalDConfDefines::ConfigPath;
+
 static constexpr char kSavePasswd[] { "savePasswd" };
 static constexpr char kStashedSmbDevices[] { "StashedSmbDevices" };
 static constexpr char kSavedPasswordType[] { "SavedPasswordType" };
@@ -91,7 +93,7 @@ QStringList DeviceManager::getAllBlockDevID(DeviceQueryOptions opts)
             && !data.value(DeviceProperty::kOptical).toBool())
             continue;
         if (opts.testFlag(DeviceQueryOption::kSystem)
-            && !DeviceUtils::isSystemDisk(data))
+            && !DeviceUtils::isBuiltInDisk(data))
             continue;
         if (opts.testFlag(DeviceQueryOption::kLoop)
             && !data.value(DeviceProperty::kIsLoopDevice).toBool())
@@ -170,6 +172,15 @@ void DeviceManager::mountBlockDevAsync(const QString &id, const QVariantMap &opt
         return;
     }
 
+    QVariantMap options = opts;
+    const QStringList winFS { "ntfs", "vfat", "exfat" };
+    if (winFS.contains(dev->fileSystem())) {
+        auto optStr = options.value("options").toString();
+        optStr.prepend("dmask=000,fmask=000,");
+        if (optStr.endsWith(",")) optStr.chop(1);
+        options.insert("options", optStr);
+    }
+
     if (dev->optical()) {
         if (d->isMountingOptical) {
             qCWarning(logDFMBase) << "Currently mounting a disc!";
@@ -193,7 +204,7 @@ void DeviceManager::mountBlockDevAsync(const QString &id, const QVariantMap &opt
         connect(fw, &QFutureWatcher<void>::finished, this, [=]() {
             qCInfo(logDFMBase) << "query optical item info finished, about to starting mounting it...";
             d->isMountingOptical = false;
-            dev->mountAsync(opts, callback);
+            dev->mountAsync(options, callback);
             delete fw;
         });
         d->isMountingOptical = true;
@@ -236,7 +247,7 @@ void DeviceManager::mountBlockDevAsync(const QString &id, const QVariantMap &opt
                     retryMount(id, DeviceType::kBlockDevice, timeout + 1);   // if device not mounted, mount it again
                 }
             };
-            dev->mountAsync(opts, callback);
+            dev->mountAsync(options, callback);
         } else {
             qCWarning(logDFMBase) << "device is not mountable: " << errMsg << id;
             if (cb)
@@ -722,7 +733,7 @@ void DeviceManager::mountNetworkDeviceAsync(const QString &address, CallbackType
     auto func = std::bind(DeviceManagerPrivate::askForPasswdWhenMountNetworkDevice, _1, _2, _3, address);
 
     auto wrappedCb = [=](bool ok, const OperationErrorInfo &err, const QString &msg) {
-        Q_EMIT mountNetworkDeviceResult(ok, err.code, msg);
+        Q_EMIT mountNetworkDeviceResult(address, ok, err.code, err.code == DeviceError::kNoError ? msg : err.message);
         if (cb) cb(ok, err, msg);
         QApplication::restoreOverrideCursor();
     };
@@ -849,9 +860,11 @@ void DeviceManager::detachAllProtoDevs()
 
 void DeviceManager::detachProtoDev(const QString &id)
 {
-    unmountProtocolDevAsync(id, {}, [id](bool ok, const OperationErrorInfo &err) {
-        if (!ok)
+    unmountProtocolDevAsync(id, {}, [this, id](bool ok, const OperationErrorInfo &err) {
+        if (!ok) {
             qCWarning(logDFMBase) << "unmount protocol device failed: " << id << err.message << err.code;
+            emit protocolDevUnmountAsyncFailed(id, err.code);
+        }
     });
 }
 
@@ -1065,38 +1078,33 @@ MountPassInfo DeviceManagerPrivate::askForPasswdWhenMountNetworkDevice(const QSt
 
     DFMMOUNT::MountPassInfo info;
     QApplication::restoreOverrideCursor();
-    if (dlg.exec() == QDialog::Accepted) {
-        QJsonObject loginInfo = dlg.getLoginData();
-        bool smbIntegrationEnabled = Application::genericAttribute(Application::GenericAttribute::kMergeTheEntriesOfSambaSharedFolders).toBool();
-        if (!uri.startsWith(Global::Scheme::kSmb) || !smbIntegrationEnabled) {
-            if (loginInfo.value(kSavePasswd).toInt() == 1)   // ftp mount with auth one time mode
-                loginInfo.insert(kSavePasswd, 0);   // set to never save password
-        }
 
-        auto data = loginInfo.toVariantMap();
-        using namespace GlobalServerDefines::NetworkMountParamKey;
-        if (data.contains(kAnonymous) && data.value(kAnonymous).toBool()) {
-            info.anonymous = true;
-        } else {
-            info.userName = data.value(kUser).toString();
-            info.domain = data.value(kDomain).toString();
-            QString pwd = data.value(kPasswd).toString();
-            info.passwd = DProtocolDevice::isMountByDaemon(uri) ? encryptPasswd(pwd) : pwd;
-            info.savePasswd = static_cast<DFMMOUNT::NetworkMountPasswdSaveMode>(
-                    data.value(kPasswdSaveMode).toInt());
-            if (uri.startsWith(Global::Scheme::kSmb)) {
-                QVariantHash pwTypeData = Application::genericSetting()->value(kStashedSmbDevices, kSavedPasswordType, QVariantHash()).toHash();
-                const QString &key = QUrl(uri).toString(QUrl::RemovePath);
-                int newPwType = int(info.savePasswd);
-                int savedPwType = pwTypeData.value(key, -1).toInt();
-                if (savedPwType != int(NetworkMountPasswdSaveMode::kSavePermanently)) {
-                    pwTypeData.insert(key, newPwType);
-                    Application::genericSetting()->setValue(kStashedSmbDevices, kSavedPasswordType, pwTypeData);
-                }
-            }
-        }
-    } else {
+    // 将对话框手动关闭，以及用户取消输入都作为取消操作
+    if (dlg.exec() != QDialog::Accepted) {
         info.cancelled = true;
+        QApplication::setOverrideCursor(Qt::WaitCursor);
+        return info;
+    }
+
+    QJsonObject loginInfo = dlg.getLoginData();
+    auto data = loginInfo.toVariantMap();
+    using namespace GlobalServerDefines::NetworkMountParamKey;
+    if (data.value(kAnonymous, false).toBool()) {
+        info.anonymous = true;
+    } else {
+        info.userName = data.value(kUser).toString();
+        info.domain = data.value(kDomain).toString();
+        info.savePasswd = static_cast<DFMMOUNT::NetworkMountPasswdSaveMode>(data.value(kPasswdSaveMode).toInt());
+        QString pwd = data.value(kPasswd).toString();
+        info.passwd = DProtocolDevice::isMountByDaemon(uri) ? encryptPasswd(pwd) : pwd;
+
+        // save password in session if samba is integrated.
+        if (uri.startsWith(Global::Scheme::kSmb)) {
+            using AppGA = Application::GenericAttribute;
+            bool smbIntegrated = Application::genericAttribute(AppGA::kMergeTheEntriesOfSambaSharedFolders).toBool();
+            if (smbIntegrated && info.savePasswd != dfmmount::NetworkMountPasswdSaveMode::kSavePermanently)
+                info.savePasswd = NetworkMountPasswdSaveMode::kSaveBeforeLogout;
+        }
     }
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
@@ -1105,7 +1113,7 @@ MountPassInfo DeviceManagerPrivate::askForPasswdWhenMountNetworkDevice(const QSt
 
 QString DeviceManagerPrivate::encryptPasswd(const QString &passwd)
 {
-    //todo use encrypt-plugin
+    // todo use encrypt-plugin
     QByteArray byteArray = passwd.toUtf8();
     QByteArray encodedByteArray = byteArray.toBase64();
     return QString::fromUtf8(encodedByteArray);
@@ -1145,7 +1153,6 @@ int DeviceManagerPrivate::askForUserChoice(const QString &message, const QString
     askForChoice.setTitle(title);
     askForChoice.setMessage(newMsg);
     askForChoice.addButtons(choices);
-    askForChoice.setMaximumWidth(480);
 
     return askForChoice.exec();
 }
