@@ -8,6 +8,7 @@
 #include <dfm-base/interfaces/fileinfo.h>
 #include <dfm-base/base/schemefactory.h>
 #include <dfm-base/base/device/deviceutils.h>
+#include <dfm-base/utils/protocolutils.h>
 #include <dfm-base/mimetype/mimesappsmanager.h>
 #include <dfm-base/mimetype/mimetypedisplaymanager.h>
 #include <dfm-base/utils/desktopfile.h>
@@ -20,6 +21,7 @@
 #include <dfm-base/utils/networkutils.h>
 #include <dfm-base/dfm_event_defines.h>
 #include <dfm-base/dbusservice/global_server_defines.h>
+#include <dfm-base/utils/protocolutils.h>
 
 #include <dfm-io/doperator.h>
 #include <dfm-io/dfile.h>
@@ -68,18 +70,21 @@ LocalFileHandler::~LocalFileHandler()
  */
 QUrl LocalFileHandler::touchFile(const QUrl &url, const QUrl &tempUrl /*= QUrl()*/)
 {
+    if (!url.isValid()) {
+        qCWarning(logDFMBase) << "Invalid URL provided to touchFile:" << url;
+        return QUrl();
+    }
+
     QSharedPointer<DFMIO::DOperator> oper { new DFMIO::DOperator(url) };
     if (!oper) {
-        qCWarning(logDFMBase) << "create operator failed, url: " << url;
+        qCWarning(logDFMBase) << "Create operator failed, url: " << url;
         return QUrl();
     }
 
     bool success = oper->touchFile();
     if (!success) {
-        qCWarning(logDFMBase) << "touch file failed, url: " << url;
-
+        qCWarning(logDFMBase) << "Touch file failed, url: " << url;
         d->setError(oper->lastError());
-
         return QUrl();
     } else {   // fix bug 189699 When the iPhone creates a file, the gio is created successfully, but there is no file
         auto info = InfoFactory::create<FileInfo>(url, Global::CreateFileInfoType::kCreateFileInfoSync);
@@ -90,7 +95,7 @@ QUrl LocalFileHandler::touchFile(const QUrl &url, const QUrl &tempUrl /*= QUrl()
     }
 
     auto templateUrl = d->loadTemplateInfo(url, tempUrl);
-    qCInfo(logDFMBase, "touchFile source file : %s, Template file %s, successed by dfmio function touchFile!",
+    qCInfo(logDFMBase, "touchFile source file: %s, Template file %s, succeeded by dfmio function touchFile!",
            url.path().toStdString().c_str(), tempUrl.path().toStdString().c_str());
     FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType::kFileAdded, url);
 
@@ -163,7 +168,7 @@ bool LocalFileHandler::rmdir(const QUrl &url)
  */
 bool LocalFileHandler::renameFile(const QUrl &url, const QUrl &newUrl, const bool needCheck)
 {
-    if (!dfmbase::FileUtils::isLocalFile(url) || !dfmbase::FileUtils::isLocalFile(newUrl))
+    if (!url.isLocalFile() || !newUrl.isLocalFile())
         return false;
 
     if (url.scheme() != newUrl.scheme())
@@ -178,7 +183,7 @@ bool LocalFileHandler::renameFile(const QUrl &url, const QUrl &newUrl, const boo
     }
 
     // check device, use set displayname if device is mtp
-    if (Q_UNLIKELY(FileUtils::isMtpFile(newUrl))) {
+    if (Q_UNLIKELY(ProtocolUtils::isMTPFile(newUrl))) {
         const QUrl &fromParentUrl = UrlRoute::urlParent(url);
         const QUrl &toParentUrl = UrlRoute::urlParent(newUrl);
         if (fromParentUrl == toParentUrl) {
@@ -270,76 +275,36 @@ bool LocalFileHandler::openFiles(const QList<QUrl> &fileUrls)
     if (fileUrls.isEmpty())
         return true;
 
-    QList<QUrl> urls = fileUrls;
-
     QList<QUrl> pathList;
     bool result = false;
     d->invalidPath.clear();
-    for (QUrl &fileUrl : urls) {
-        FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(fileUrl);
-        QUrl sourceUrl = fileUrl;
-        QStringList targetList;
-        targetList.append(fileUrl.path());
-        FileInfoPointer fileInfoLink = fileInfo;
 
-        while (fileInfoLink->isAttributes(OptInfoType::kIsSymLink)) {
-            QString targetLink = fileInfoLink->pathOf(PathInfoType::kSymLinkTarget);
-            targetLink = targetLink.endsWith(QDir::separator()) && targetLink != QDir::separator() ? QString(targetLink).left(targetLink.length() - 1)
-                                                                                                   : targetLink;
-            if (targetList.contains(targetLink))
-                break;
-            targetList.append(targetLink);
-            // 网络文件检查
-            if (NetworkUtils::instance()->checkFtpOrSmbBusy(QUrl::fromLocalFile(targetLink))) {
-                DialogManager::instance()->showUnableToVistDir(targetLink);
-                return true;
-            }
-            fileInfoLink = InfoFactory::create<FileInfo>(QUrl::fromLocalFile(targetLink));
-            if (!fileInfoLink) {
-                DialogManagerInstance->showErrorDialog(QObject::tr("Unable to find the original file"), QString());
-                return false;
-            }
-            const_cast<QUrl &>(fileUrl) = fileInfoLink->urlOf(UrlInfoType::kRedirectedFileUrl);
-            if (d->isInvalidSymlinkFile(fileUrl)) {
-                d->lastEvent = DialogManagerInstance->showBreakSymlinkDialog(fileInfoLink->nameOf(
-                                                                                     NameInfoType::kFileName),
-                                                                             fileInfo->urlOf(UrlInfoType::kUrl));
-                d->invalidPath << sourceUrl;
-                return d->lastEvent == DFMBASE_NAMESPACE::GlobalEventType::kUnknowType;
-            }
-        }
-
-        if (d->isExecutableScript(fileUrl.path())) {
-            int code = DialogManagerInstance->showRunExcutableScriptDialog(fileUrl);
-            result = d->openExcutableScriptFile(fileUrl.path(), code) || result;
+    // Process each file
+    for (const QUrl &fileUrl : fileUrls) {
+        // Skip invalid URLs
+        if (!fileUrl.isValid() || !fileUrl.isLocalFile()) {
+            qCWarning(logDFMBase) << "Invalid URL provided:" << fileUrl;
             continue;
         }
 
-        if (d->isFileRunnable(fileUrl.path()) && !FileUtils::isDesktopFile(fileUrl)) {
-            int code = DialogManagerInstance->showRunExcutableFileDialog(fileUrl);
-            result = d->openExcutableFile(fileUrl.path(), code) || result;
+        // 1. Handle symlinks
+        auto resolvedUrl = d->resolveSymlink(fileUrl);
+        if (!resolvedUrl)   // If resolution fails, continue to next file
             continue;
-        }
 
-        if (d->shouldAskUserToAddExecutableFlag(fileUrl.path()) && !FileUtils::isDesktopFile(fileUrl)) {
-            int code = DialogManagerInstance->showAskIfAddExcutableFlagAndRunDialog();
-            result = d->addExecutableFlagAndExecuse(fileUrl.path(), code) || result;
+        // 2. Handle executable files
+        if (d->handleExecutableFile(*resolvedUrl, &result))
             continue;
-        }
 
-        QString urlPath = fileUrl.path();
-        if (d->isFileWindowsUrlShortcut(urlPath)) {
-            urlPath = d->getInternetShortcutUrl(urlPath);
-            pathList << QUrl::fromLocalFile(urlPath);
-        } else {
-            pathList << fileUrl;
-        }
+        // 3. Collect file paths to open
+        d->collectFilePath(*resolvedUrl, &pathList);
     }
 
+    // 4. Open collected files
     if (!pathList.empty()) {
         result = d->doOpenFiles(pathList);
     } else {
-        return true;
+        result = d->invalidPath.isEmpty();
     }
 
     return result;
@@ -590,14 +555,28 @@ bool LocalFileHandler::deleteFile(const QUrl &url)
 bool LocalFileHandler::deleteFileRecursive(const QUrl &url)
 {
     qCInfo(logDFMBase) << "Recursive delete " << url;
+
+    if (!url.isValid()) {
+        qCWarning(logDFMBase) << "Invalid URL provided to deleteFileRecursive:" << url;
+        return false;
+    }
+
     if (SystemPathUtil::instance()->isSystemPath(url.toLocalFile())) {
         qCWarning(logDFMBase) << "Cannot delete system path!!!!!!!!!!!!!!!!!";
         abort();
     }
 
     FileInfoPointer info { InfoFactory::create<FileInfo>(url) };
-    if (!info)
+    if (!info) {
+        qCWarning(logDFMBase) << "Failed to create FileInfo for:" << url;
         return false;
+    }
+
+    // 首先检查是否是符号链接，如果是则只删除链接本身
+    if (info->isAttributes(OptInfoType::kIsSymLink)) {
+        qCInfo(logDFMBase) << "Delete symbolic link: " << url;
+        return deleteFile(url);
+    }
 
     if (!info->isAttributes(OptInfoType::kIsDir))
         return deleteFile(url);
@@ -612,6 +591,11 @@ bool LocalFileHandler::deleteFileRecursive(const QUrl &url)
     while (enumerator->hasNext()) {
         const QUrl &urlNext = enumerator->next();
         info = InfoFactory::create<FileInfo>(urlNext);
+        if (!info) {
+            qCWarning(logDFMBase) << "Failed to create FileInfo for:" << urlNext;
+            continue;
+        }
+
         if (info->isAttributes(OptInfoType::kIsDir))
             succ = deleteFileRecursive(urlNext);
         else
@@ -655,56 +639,7 @@ bool LocalFileHandlerPrivate::launchApp(const QString &desktopFilePath, const QS
 
     // url path will be truncated at the index of '#', so replace it if it's real existed in url. (mostly it's for avfs archive paths)
     std::for_each(newFileUrls.begin(), newFileUrls.end(), [](QString &path) { path.replace("#", "%23"); });
-    bool ok = launchAppByDBus(desktopFilePath, newFileUrls);
-    if (!ok) {
-        ok = launchAppByGio(desktopFilePath, newFileUrls);
-    }
-    return ok;
-}
-
-bool LocalFileHandlerPrivate::launchAppByDBus(const QString &desktopFile, const QStringList &filePaths)
-{
-    qCInfo(logDFMBase, "launch App By DBus, desktopFile : %s, files count : %d !", desktopFile.toStdString().c_str(), filePaths.count());
-    qCDebug(logDFMBase) << "launch App By DBus, files : \n"
-                        << filePaths;
-    if (UniversalUtils::checkLaunchAppInterface())
-        return UniversalUtils::launchAppByDBus(desktopFile, filePaths);
-    return false;
-}
-
-bool LocalFileHandlerPrivate::launchAppByGio(const QString &desktopFilePath, const QStringList &fileUrls)
-{
-    qCDebug(logDFMBase) << "launchApp by gio:" << desktopFilePath << fileUrls;
-
-    const QByteArray &cDesktopFilePath = desktopFilePath.toLocal8Bit();
-
-    g_autoptr(GDesktopAppInfo) appInfo = g_desktop_app_info_new_from_filename(cDesktopFilePath.data());
-    if (!appInfo) {
-        qCWarning(logDFMBase) << "Failed to open desktop file with gio: g_desktop_app_info_new_from_filename returns NULL. Check PATH maybe?";
-        return false;
-    }
-
-    GList *gfiles = nullptr;
-    foreach (const QString &url, fileUrls) {
-        const QByteArray &cFilePath = url.toLocal8Bit();
-        GFile *gfile = g_file_new_for_uri(cFilePath.data());
-        gfiles = g_list_append(gfiles, gfile);
-    }
-
-    g_autoptr(GError) gerror = nullptr;
-    gboolean ok = g_app_info_launch(reinterpret_cast<GAppInfo *>(appInfo), gfiles, nullptr, &gerror);
-
-    if (gerror) {
-        qCWarning(logDFMBase) << "Error when trying to open desktop file with gio:" << gerror->message;
-    }
-
-    if (!ok) {
-        qCWarning(logDFMBase) << "Failed to open desktop file with gio: g_app_info_launch returns false";
-    }
-    if (gfiles)
-        g_list_free(gfiles);
-
-    return ok;
+    return AppLaunchUtils::instance().launchApp(desktopFilePath, newFileUrls);
 }
 
 bool LocalFileHandlerPrivate::isFileManagerSelf(const QString &desktopFile)
@@ -723,7 +658,7 @@ bool LocalFileHandlerPrivate::isInvalidSymlinkFile(const QUrl &url)
         return true;
 
     const QString &path { info->pathOf(PathInfoType::kAbsoluteFilePath) };
-    if (!DFMIO::DFile(path).exists() && !DeviceUtils::isSamba(url))
+    if (!DFMIO::DFile(path).exists() && !ProtocolUtils::isSMBFile(url))
         return true;
 
     return false;
@@ -828,11 +763,8 @@ bool LocalFileHandlerPrivate::isFileExecutable(const QString &path)
     if (kinValidateType.contains(info->nameOf(NameInfoType::kSuffix)))
         return false;
 
-    QFile::Permissions permissions { info->permissions() };
-    bool isExeUser = permissions & QFile::Permission::ExeUser;
-    bool isReadUser = permissions & QFile::Permission::ReadUser;
-
-    return isExeUser && isReadUser;
+    return info->isAttributes(FileInfo::FileIsType::kIsExecutable)
+            && info->isAttributes(FileInfo::FileIsType::kIsReadable);
 }
 
 bool LocalFileHandlerPrivate::openExcutableScriptFile(const QString &path, int flag)
@@ -1024,9 +956,21 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
 
     QList<QUrl> transUrls = urls;
     for (const QUrl &url : urls) {
-        FileInfoPointer info { InfoFactory::create<FileInfo>(url) };
+        if (!url.isValid()) {
+            qCWarning(logDFMBase) << "Invalid URL skipped:" << url;
+            transUrls.removeOne(url);
+            continue;
+        }
+
+        FileInfoPointer info = InfoFactory::create<FileInfo>(url);
+        if (!info) {
+            qCWarning(logDFMBase) << "Failed to create FileInfo for:" << url;
+            transUrls.removeOne(url);
+            continue;
+        }
+
         if (info->nameOf(NameInfoType::kSuffix) == Global::Scheme::kDesktop) {
-            ret = launchApp(url.path()) || ret;   //有一个成功就成功
+            ret = launchApp(url.path()) || ret;   // Success if at least one succeeds
             transUrls.removeOne(url);
             continue;
         }
@@ -1034,7 +978,7 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
     if (transUrls.isEmpty())
         return ret;
 
-    // 找出所有可以打开的文件的信息，这里比较耗时，需要优化
+    // Find information for all openable files, this is time-consuming and needs optimization
     QMultiMap<QString, QString> openInfos, mountOpenInfos, cmdOpenInfos;
     QMap<QString, QString> openMineTypes, mountMineTypes, cmdMineTypes;
     for (auto url : transUrls) {
@@ -1042,6 +986,10 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
         const QString &filePath = fileUrl.path();
 
         FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(fileUrl);
+        if (!fileInfo) {
+            qCWarning(logDFMBase) << "Failed to create FileInfo for:" << fileUrl;
+            continue;
+        }
 
         QString mimeType;
         if (Q_UNLIKELY(!filePath.contains("#")) && fileInfo && fileInfo->size() == 0 && fileInfo->exists()) {
@@ -1070,7 +1018,7 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
                     mountMineTypes.insert(DeviceUtils::getSambaFileUriFromNative(fileUrl).toString(),
                                           QString("inode/directory"));
                 } else {
-                    qCWarning(logDFMBase) << "no default application for" << fileUrl;
+                    qCWarning(logDFMBase) << "No default application for" << fileUrl;
                 }
                 continue;
             }
@@ -1083,7 +1031,7 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
                     cmdOpenInfos.insert(defaultDesktopFile, url.toString());
                     cmdMineTypes.insert(url.toString(), mimeType);
                 } else {
-                    qCWarning(logDFMBase) << "no default application for" << transUrls;
+                    qCWarning(logDFMBase) << "No default application for" << transUrls;
                     continue;
                 }
             }
@@ -1093,20 +1041,18 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
         }
     }
 
-    // 打开所有的文件
+    // Open all files
     if (openInfos.isEmpty() && mountOpenInfos.isEmpty() && cmdOpenInfos.isEmpty())
         return false;
 
     bool openResult = doOpenFiles(openInfos, openMineTypes);
-
     bool openMount = doOpenFiles(mountOpenInfos, mountMineTypes);
-
     bool openCmd = doOpenFiles(cmdOpenInfos, cmdMineTypes);
 
     if (openResult || openMount || openCmd)
         return true;
 
-    if (DeviceUtils::isSamba(transUrls[0]))
+    if (!transUrls.isEmpty() && ProtocolUtils::isSMBFile(transUrls[0]))
         return false;
 
     QStringList paths;
@@ -1114,7 +1060,7 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
         paths << url.path();
     }
 
-    if (MimesAppsManager::getDefaultAppByFileName(transUrls.first().path()) == "org.gnome.font-viewer.desktop") {
+    if (!transUrls.isEmpty() && MimesAppsManager::getDefaultAppByFileName(transUrls.first().path()) == "org.gnome.font-viewer.desktop") {
         QProcess::startDetached("gio", QStringList() << "open" << paths);
         QTimer::singleShot(200, [=] {
             QProcess::startDetached("gio", QStringList() << "open" << paths);
@@ -1127,7 +1073,7 @@ bool LocalFileHandlerPrivate::doOpenFiles(const QList<QUrl> &urls, const QString
     if (!result) {
         result = false;
         for (const QUrl &url : transUrls)
-            result = QDesktopServices::openUrl(url) || result;   //有一个成功就成功
+            result = QDesktopServices::openUrl(url) || result;   // 有一个成功就成功
     }
     return result;
 }
@@ -1177,7 +1123,7 @@ bool LocalFileHandler::renameFilesBatch(const QMap<QUrl, QUrl> &urls, QMap<QUrl,
                 return true;
         }
 
-        ///###: just cache files that rename successfully.
+        /// ###: just cache files that rename successfully.
         if (renameFile(currentName, expectedName, false)) {
             successUrls[currentName] = expectedName;
         }
@@ -1281,3 +1227,119 @@ LocalFileHandlerPrivate::LocalFileHandlerPrivate(LocalFileHandler *handler)
     : q(handler)
 {
 }
+
+// 处理符号链接解析
+std::optional<QUrl> LocalFileHandlerPrivate::resolveSymlink(const QUrl &url)
+{
+    if (!url.isValid()) {
+        qCWarning(logDFMBase) << "Invalid URL provided to resolveSymlink:" << url;
+        return std::nullopt;
+    }
+
+    // Track visited paths to detect circular links
+    QStringList visitedPaths;
+    QString currentPath = url.toLocalFile();
+    visitedPaths << currentPath;
+
+    QFileInfo fileInfo(currentPath);
+    while (fileInfo.isSymLink()) {
+        // Get absolute path of link target (automatically handles relative paths)
+        QString canonicalPath = fileInfo.canonicalFilePath();
+
+        // If canonical path retrieval fails, link may be broken
+        if (canonicalPath.isEmpty()) {
+            FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(url);
+            if (!fileInfo) {
+                qCWarning(logDFMBase) << "Failed to create FileInfo for:" << url;
+                return std::nullopt;
+            }
+
+            QString targetLink = fileInfo->pathOf(PathInfoType::kSymLinkTarget);
+            canonicalPath = SystemPathUtil::instance()->getRealpathSafely(targetLink);
+        }
+
+        if (canonicalPath.isEmpty()) {
+            DialogManagerInstance->showErrorDialog(QObject::tr("Unable to find the original file"), QString());
+            return std::nullopt;
+        }
+
+        // Check for circular links
+        if (visitedPaths.contains(canonicalPath))
+            break;   // Circular link detected, use last valid path
+
+        visitedPaths << canonicalPath;
+
+        // Network file check
+        if (NetworkUtils::instance()->checkFtpOrSmbBusy(QUrl::fromLocalFile(canonicalPath))) {
+            DialogManager::instance()->showUnableToVistDir(canonicalPath);
+            return std::nullopt;
+        }
+
+        // Check if link target exists
+        fileInfo.setFile(canonicalPath);
+        if (!fileInfo.exists() && !ProtocolUtils::isSMBFile(QUrl::fromLocalFile(canonicalPath))) {
+            // Link is broken
+            lastEvent = DialogManagerInstance->showBreakSymlinkDialog(
+                    QFileInfo(currentPath).fileName(),
+                    url);
+            invalidPath << url;
+            return std::nullopt;
+        }
+
+        currentPath = canonicalPath;
+    }
+
+    // Return final resolved URL (if circular link, returns last valid path)
+    return QUrl::fromLocalFile(currentPath);
+}
+
+// 处理可执行文件
+bool LocalFileHandlerPrivate::handleExecutableFile(const QUrl &fileUrl, bool *result)
+{
+    if (!fileUrl.isValid() || !result) {
+        qCWarning(logDFMBase) << "Invalid parameters to handleExecutableFile";
+        return false;
+    }
+
+    // Handle executable scripts
+    if (isExecutableScript(fileUrl.path())) {
+        int code = DialogManagerInstance->showRunExcutableScriptDialog(fileUrl);
+        *result = openExcutableScriptFile(fileUrl.path(), code) || *result;
+        return true;
+    }
+
+    // Handle runnable files
+    if (isFileRunnable(fileUrl.path()) && !FileUtils::isDesktopFile(fileUrl)) {
+        int code = DialogManagerInstance->showRunExcutableFileDialog(fileUrl);
+        *result = openExcutableFile(fileUrl.path(), code) || *result;
+        return true;
+    }
+
+    // Handle files that need executable permission
+    if (shouldAskUserToAddExecutableFlag(fileUrl.path()) && !FileUtils::isDesktopFile(fileUrl)) {
+        int code = DialogManagerInstance->showAskIfAddExcutableFlagAndRunDialog();
+        *result = addExecutableFlagAndExecuse(fileUrl.path(), code) || *result;
+        return true;
+    }
+
+    return false;
+}
+
+// Collect file paths to open
+void LocalFileHandlerPrivate::collectFilePath(const QUrl &fileUrl, QList<QUrl> *pathList)
+{
+    if (!fileUrl.isValid() || !pathList) {
+        qCWarning(logDFMBase) << "Invalid parameters to collectFilePath";
+        return;
+    }
+
+    QString urlPath = fileUrl.path();
+    if (isFileWindowsUrlShortcut(urlPath)) {
+        urlPath = getInternetShortcutUrl(urlPath);
+        if (!urlPath.isEmpty()) {
+            pathList->append(QUrl::fromLocalFile(urlPath));
+        }
+    } else {
+        pathList->append(fileUrl);
+    }
+}
