@@ -7,11 +7,13 @@
 #include <dfm-base/utils/windowutils.h>
 #include <dfm-base/utils/sysinfoutils.h>
 #include <dfm-base/utils/systempathutil.h>
+#include <dfm-base/utils/protocolutils.h>
 #include <dfm-base/dfm_global_defines.h>
 #include <dfm-base/utils/dialogmanager.h>
 #include <dfm-base/base/urlroute.h>
 #include <dfm-base/utils/finallyutil.h>
 #include <dfm-base/base/device/deviceutils.h>
+#include <dfm-base/utils/networkutils.h>
 #include <dfm-base/base/device/deviceproxymanager.h>
 #include <dfm-base/base/schemefactory.h>
 #include <dfm-base/base/application/application.h>
@@ -56,13 +58,14 @@
 #include <sys/stat.h>
 #include <linux/limits.h>
 
-#ifdef COMPILE_ON_V23
+#ifdef COMPILE_ON_V2X
 #    define APPEARANCE_SERVICE "org.deepin.dde.Appearance1"
 #    define APPEARANCE_PATH "/org/deepin/dde/Appearance1"
 #else
 #    define APPEARANCE_SERVICE "com.deepin.daemon.Appearance"
 #    define APPEARANCE_PATH "/com/deepin/daemon/Appearance"
 #endif
+using namespace GlobalDConfDefines::ConfigPath;
 
 namespace dfmbase {
 
@@ -159,43 +162,6 @@ int FileUtils::supportedMaxLength(const QString &fileSystem)
     return datas.value(fileSystem.toLower(), 11);
 }
 
-bool FileUtils::isGvfsFile(const QUrl &url)
-{
-    if (!url.isValid())
-        return false;
-
-    const QString &path = url.toLocalFile();
-    static const QString gvfsMatch { "(^/run/user/\\d+/gvfs/|^/root/.gvfs/|^/media/[\\s\\S]*/smbmounts)" };
-    // TODO(xust) /media/$USER/smbmounts might be changed in the future.
-    QRegularExpression re { gvfsMatch };
-    QRegularExpressionMatch match { re.match(path) };
-    return match.hasMatch();
-}
-
-bool FileUtils::isMtpFile(const QUrl &url)
-{
-    if (!url.isValid())
-        return false;
-
-    const QString &path = url.toLocalFile();
-    static const QString gvfsMatch { R"(^/run/user/\d+/gvfs/mtp:host|^/root/.gvfs/mtp:host)" };
-    QRegularExpression re { gvfsMatch };
-    QRegularExpressionMatch match { re.match(path) };
-    return match.hasMatch();
-}
-
-bool FileUtils::isGphotoFile(const QUrl &url)
-{
-    if (!url.isValid())
-        return false;
-
-    const QString &path = url.toLocalFile();
-    static const QString gvfsMatch { R"(^/run/user/\d+/gvfs/gphoto2:host|^/root/.gvfs/gphoto2:host)" };
-    QRegularExpression re { gvfsMatch };
-    QRegularExpressionMatch match { re.match(path) };
-    return match.hasMatch();
-}
-
 QString FileUtils::preprocessingFileName(QString name)
 {
     // eg: [\\:*\"?<>|\r\n]
@@ -290,9 +256,7 @@ bool FileUtils::isDesktopFileInfo(const FileInfoPointer &info)
 {
     Q_ASSERT(info);
     const QString &suffix = info->nameOf(NameInfoType::kSuffix);
-    if (suffix == DFMBASE_NAMESPACE::Global::Scheme::kDesktop
-        || info->urlOf(UrlInfoType::kParentUrl).path() == StandardPaths::location(StandardPaths::StandardLocation::kDesktopPath)
-        || info->extendAttributes(ExtInfoType::kFileLocalDevice).toBool()) {
+    if (suffix == DFMBASE_NAMESPACE::Global::Scheme::kDesktop) {
         const QUrl &url = info->urlOf(UrlInfoType::kUrl);
         QMimeType type = info->fileMimeType();
         if (!type.isValid())
@@ -307,6 +271,12 @@ bool FileUtils::isDesktopFileInfo(const FileInfoPointer &info)
     return false;
 }
 
+void FileUtils::refreshIconCache()
+{
+    // https://bugreports.qt.io/browse/QTBUG-112257
+    QIcon::setThemeSearchPaths(QIcon::themeSearchPaths());
+}
+
 bool FileUtils::isTrashDesktopFile(const QUrl &url)
 {
     if (isDesktopFileSuffix(url)) {
@@ -339,7 +309,7 @@ bool FileUtils::isSameDevice(const QUrl &url1, const QUrl &url2)
     if (url1.scheme() != url2.scheme())
         return false;
 
-    if (isLocalFile(url1)) {
+    if (url1.isLocalFile()) {
         return DFMIO::DFMUtils::devicePathFromUrl(url1) == DFMIO::DFMUtils::devicePathFromUrl(url2);
     }
 
@@ -356,36 +326,25 @@ bool FileUtils::isSameFile(const QUrl &url1, const QUrl &url2, const Global::Cre
     if (!info1 || !info2)
         return false;
 
-    struct stat statFromInfo;
-    struct stat statToInfo;
-
     const QString &path1 = info1->pathOf(PathInfoType::kAbsoluteFilePath);
     const QString &path2 = info2->pathOf(PathInfoType::kAbsoluteFilePath);
-    int fromStat = stat(path1.toLocal8Bit().data(), &statFromInfo);
-    int toStat = stat(path2.toLocal8Bit().data(), &statToInfo);
-    if (0 == fromStat && 0 == toStat) {
-        // 通过inode判断是否是同一个文件
-        if (statFromInfo.st_ino == statToInfo.st_ino
-            && statFromInfo.st_dev == statToInfo.st_dev) {   //! 需要判断设备号
-            return true;
-        }
-    }
-    return false;
+
+    return isSameFile(path1, path2);
 }
 
-bool FileUtils::isLocalDevice(const QUrl &url)
+bool FileUtils::isSameFile(const QString &path1, const QString &path2)
 {
-    //return !DFMIO::DFMUtils::fileIsRemovable(url) && !isGvfsFile(url);
-    if (isGvfsFile(url))
-        return false;
+    struct stat stat1;
+    struct stat stat2;
+    int ret1 = stat(path1.toLocal8Bit().data(), &stat1);
+    int ret2 = stat(path2.toLocal8Bit().data(), &stat2);
+    if (0 == ret1 && 0 == ret2) {
+        // 通过inode判断是否是同一个文件
+        return (stat1.st_ino == stat2.st_ino
+                && stat1.st_dev == stat2.st_dev);   //! 需要判断设备号
+    }
 
-    if (DeviceUtils::isExternalBlock(url))
-        return false;
-
-    if (DevProxyMng->isFileOfProtocolMounts(url.path()))
-        return false;
-
-    return true;
+    return false;
 }
 
 bool FileUtils::isCdRomDevice(const QUrl &url)
@@ -395,6 +354,13 @@ bool FileUtils::isCdRomDevice(const QUrl &url)
 
 bool FileUtils::trashIsEmpty()
 {
+    const auto &cifsHost = NetworkUtils::cifsMountHostInfo();
+    if (!cifsHost.isEmpty()) {
+        const auto &mountPoint = cifsHost.constKeyValueBegin()->first;
+        if (NetworkUtils::instance()->checkFtpOrSmbBusy(QUrl::fromLocalFile(mountPoint)))
+            return true;
+    }
+
     // not use cache, because some times info unreliable, such as watcher inited temporality
     auto info = InfoFactory::create<FileInfo>(trashRootUrl(), Global::CreateFileInfoType::kCreateFileInfoSync);
     if (info) {
@@ -449,22 +415,6 @@ bool FileUtils::isHigherHierarchy(const QUrl &urlBase, const QUrl &urlCompare)
     return false;
 }
 
-bool FileUtils::isLocalFile(const QUrl &url)
-{
-    if (url.isLocalFile())
-        return true;
-
-    // see if the original path is from local.
-    // since only ext* filesystems are supported to mounted with dlnfs,
-    // check the url by udisks.
-    // the dlnfs mount is captured by gvfs and is regarded as protocol device.
-    // so if it's NOT external block mounts file, it's local file.
-    if (DeviceUtils::isSubpathOfDlnfs(url.path()))
-        return !(DevProxyMng->isFileOfExternalBlockMounts(url.path()));
-
-    return false;
-}
-
 /*!
  * \brief FileUtils::getFileNameLength, if the `url` is suburl of dlnfs mountpoint, then use char count rather than byte count to judge filename length.
  * \param url
@@ -492,7 +442,7 @@ QMap<QUrl, QUrl> FileUtils::fileBatchReplaceText(const QList<QUrl> &originUrls,
 
         bool isDesktopApp = info->nameOf(NameInfoType::kMimeTypeName).contains(Global::Mime::kTypeAppDesktop);
 
-        ///###: symlink is also processed here.
+        /// ###: symlink is also processed here.
         const QString &suffix = info->nameOf(NameInfoType::kSuffix).isEmpty()
                 ? QString()
                 : QString(".") + info->nameOf(NameInfoType::kSuffix);
@@ -580,14 +530,14 @@ QMap<QUrl, QUrl> FileUtils::fileBatchAddText(const QList<QUrl> &originUrls, cons
 
 QMap<QUrl, QUrl> FileUtils::fileBatchCustomText(const QList<QUrl> &originUrls, const QPair<QString, QString> &pair)
 {
-    if (originUrls.isEmpty() || pair.first.isEmpty() || pair.second.isEmpty()) {   //###: here, jundge whether there are fileUrls in originUrls.
+    if (originUrls.isEmpty() || pair.first.isEmpty() || pair.second.isEmpty()) {   // ###: here, jundge whether there are fileUrls in originUrls.
         return QMap<QUrl, QUrl> {};
     }
 
     unsigned long long serialNumber { pair.second.toULongLong() };
     unsigned long long index { 0 };
 
-    if (serialNumber == ULONG_LONG_MAX) {   //##: Maybe, this value will be equal to the max value of the type of unsigned long long
+    if (serialNumber == ULONG_LONG_MAX) {   // ##: Maybe, this value will be equal to the max value of the type of unsigned long long
         index = serialNumber - originUrls.size();
     } else {
         index = serialNumber;
@@ -777,7 +727,7 @@ QString FileUtils::nonExistSymlinkFileName(const QUrl &fileUrl, const QUrl &pare
             if (parentDir.exists(linkBaseName)) {
                 ++number;
             } else {
-                //链接文件失效后exists会返回false，通过lstat再次判断链接文件本身是否存在
+                // 链接文件失效后exists会返回false，通过lstat再次判断链接文件本身是否存在
                 auto strLinkPath = parentDir.filePath(linkBaseName).toStdString();
                 struct stat st;
                 if ((lstat(strLinkPath.c_str(), &st) == 0) && S_ISLNK(st.st_mode))
@@ -1008,16 +958,16 @@ bool FileUtils::containsCopyingFileUrl(const QUrl &url)
     return copyingUrl.contains(url);
 }
 
-// TODO: remot it!
+// TODO: remove it!
 void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type, const QUrl &url)
 {
     if (!url.isValid())
         return;
 
     auto isRemoteMount = [=](const QUrl &url) -> bool {
-        if (DeviceUtils::isSamba(url))
+        if (ProtocolUtils::isSMBFile(url))
             return true;
-        if (DeviceUtils::isFtp(url))
+        if (ProtocolUtils::isFTPFile(url))
             return true;
 
         return false;
@@ -1048,8 +998,8 @@ void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type,
         return;
     }
 }
-//fix 多线程排序时，该处的全局变量在compareByString函数中可能导致软件崩溃
-//QCollator sortCollator;
+// fix 多线程排序时，该处的全局变量在compareByString函数中可能导致软件崩溃
+// QCollator sortCollator;
 class DCollator : public QCollator
 {
 public:
@@ -1063,6 +1013,10 @@ public:
 
 bool FileUtils::isNumOrChar(const QChar ch)
 {
+    QChar normalized;
+    if (isFullWidthChar(ch, normalized))
+        return isNumOrChar(normalized);
+
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     return (ch >= 48 && ch <= 57) || (ch >= 65 && ch <= 90) || (ch >= 97 && ch <= 122);
 #else
@@ -1073,6 +1027,10 @@ bool FileUtils::isNumOrChar(const QChar ch)
 
 bool FileUtils::isNumber(const QChar ch)
 {
+    QChar number;
+    if (isFullWidthChar(ch, number))
+        return isNumber(number);
+
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     return (ch >= 48 && ch <= 57);
 #else
@@ -1081,8 +1039,103 @@ bool FileUtils::isNumber(const QChar ch)
 #endif
 }
 
+bool FileUtils::isFullWidthChar(const QChar ch, QChar &normalized)
+{
+    // 全角字符的 Unicode 范围
+    ushort unicode = ch.unicode();
+
+    // 处理全角数字 (0xFF10-0xFF19)
+    if (unicode >= 0xFF10 && unicode <= 0xFF19) {
+        normalized = QChar(unicode - 0xFF10 + '0');
+        return true;
+    }
+
+    // 处理全角大写字母 (0xFF21-0xFF3A)
+    if (unicode >= 0xFF21 && unicode <= 0xFF3A) {
+        normalized = QChar(unicode - 0xFF21 + 'A');
+        return true;
+    }
+
+    // 处理全角小写字母 (0xFF41-0xFF5A)
+    if (unicode >= 0xFF41 && unicode <= 0xFF5A) {
+        normalized = QChar(unicode - 0xFF41 + 'a');
+        return true;
+    }
+
+    // 处理全角标点符号
+    static const QHash<ushort, QChar> punctuationMap {
+        { 0xFF01, '!' },   // ！
+        { 0xFF08, '(' },   // （
+        { 0xFF09, ')' },   // ）
+        { 0xFF0C, ',' },   // ，
+        { 0xFF1A, ':' },   // ：
+        { 0xFF1B, ';' },   // ；
+        { 0xFF1F, '?' },   // ？
+        { 0xFF3B, '[' },   // ［
+        { 0xFF3D, ']' },   // ］
+        { 0xFF5B, '{' },   // ｛
+        { 0xFF5D, '}' },   // ｝
+        { 0xFF0E, '.' },   // ．
+        { 0xFF0F, '/' },   // ／
+        { 0xFF3F, '_' },   // ＿
+        { 0xFF0D, '-' },   // －
+        { 0xFF1D, '=' },   // ＝
+        { 0xFF06, '&' },   // ＆
+        { 0xFF5C, '|' },   // ｜
+        { 0xFF1C, '<' },   // ＜
+        { 0xFF1E, '>' },   // ＞
+        { 0xFF02, '"' },   // ＂
+        { 0xFF07, '\'' },   // ＇
+        { 0xFF0B, '+' },   // ＋
+        { 0xFF03, '#' },   // ＃
+        { 0xFF04, '$' },   // ＄
+        { 0xFF05, '%' },   // ％
+        { 0xFF20, '@' },   // ＠
+        { 0xFF0A, '*' },   // ＊
+        { 0xFF3C, '\\' },   // ＼
+        { 0xFF5E, '~' }   // ～
+    };
+
+    auto it = punctuationMap.find(unicode);
+    if (it != punctuationMap.end()) {
+        normalized = it.value();
+        return true;
+    }
+
+    return false;
+}
+
+QString FileUtils::makeQString(const QString::const_iterator &it, uint unicode)
+{
+    if (it->isHighSurrogate()) {
+        QString str(QChar::highSurrogate(unicode));
+        str.append(QChar::lowSurrogate(unicode));
+        return str;
+    }
+    return *it;
+}
+
+QString FileUtils::symlinkTarget(const QUrl &url)
+{
+    char buffer[4096] { 0 };
+    auto size = readlink(url.path().toStdString().c_str(), buffer, sizeof(buffer));
+    if (size > 0)
+        return QString::fromUtf8(buffer, static_cast<int>(size));
+    return QString();
+}
+
 bool FileUtils::isSymbol(const QChar ch)
 {
+    // 如果是高代理项，不应该单独判断
+    if (ch.isHighSurrogate() || ch.isLowSurrogate())
+        return false;
+
+    QChar normalized;
+    if (isFullWidthChar(ch, normalized)) {
+        return isSymbol(normalized);
+    }
+
+    // 对于普通字符进行原有判断
     return ch.script() != QChar::Script_Han && !isNumOrChar(ch);
 }
 
@@ -1099,7 +1152,13 @@ QString FileUtils::numberStr(const QString &str, int pos)
         pos++;
 
     while (pos < total && isNumber(str.at(pos))) {
-        tmp += str.at(pos);
+        const QChar &ch = str.at(pos);
+        QChar number;
+        if (isFullWidthChar(ch, number)) {
+            tmp += number;   // 将全角数字转换为半角数字
+        } else {
+            tmp += ch;
+        }
         pos++;
     }
 
@@ -1114,67 +1173,125 @@ bool FileUtils::compareByStringEx(const QString &str1, const QString &str2)
     QString suf2 = str2.right(str2.length() - str2.lastIndexOf(".") - 1);
     QString name1 = str1.left(str1.lastIndexOf("."));
     QString name2 = str2.left(str2.lastIndexOf("."));
-    int length1 = name1.length();
-    int length2 = name2.length();
-    auto total = length1 > length2 ? length2 : length1;
 
     bool preIsNum = false;
-    bool isSybol1 = false, isSybol2 = false, isHanzi1 = false,
+    bool isSymbol1 = false, isSymbol2 = false, isHanzi1 = false,
          isHanzi2 = false, isNumb1 = false, isNumb2 = false;
-    for (int i = 0; i < total; ++i) {
-        // 判断相等和大小写相等，跳过
-        if (str1.at(i) == str2.at(i) || str1.at(i).toLower() == str2.at(i).toLower()) {
-            preIsNum = isNumber(str1.at(i));
+
+    // 使用迭代器来正确处理代理对字符
+    QString::const_iterator it1 = name1.constBegin();
+    QString::const_iterator it2 = name2.constBegin();
+
+    while (it1 != name1.constEnd() && it2 != name2.constEnd()) {
+        // 获取当前完整字符(可能是代理对)
+        uint unicode1 = it1->isHighSurrogate() && (it1 + 1) != name1.constEnd()
+                ? QChar::surrogateToUcs4(*it1, *(it1 + 1))
+                : it1->unicode();
+        uint unicode2 = it2->isHighSurrogate() && (it2 + 1) != name2.constEnd()
+                ? QChar::surrogateToUcs4(*it2, *(it2 + 1))
+                : it2->unicode();
+
+        // 如果字符相同，继续比较下一个
+        if (unicode1 == unicode2) {
+            preIsNum = isNumber(*it1);
+            if (it1->isHighSurrogate()) {
+                ++it1;
+                ++it2;
+            }
+            ++it1;
+            ++it2;
             continue;
         }
-        isNumb1 = isNumber(str1.at(i));
-        isNumb2 = isNumber(str2.at(i));
+
+        // 处理数字
+        QChar number1, number2;
+        isNumb1 = !it1->isHighSurrogate() && isNumber(*it1);
+        isNumb2 = !it2->isHighSurrogate() && isNumber(*it2);
+
         if ((preIsNum && (isNumb1 ^ isNumb2)) || (isNumb1 && isNumb2)) {
-            // 取后面几位的数字作比较后面的数字,先比较位数
-            // 位数大的大
-            auto str1n = numberStr(str1, preIsNum ? i - 1 : i).toUInt();
-            auto str2n = numberStr(str2, preIsNum ? i - 1 : i).toUInt();
-            if (str1n == str2n)
-                return str1.at(i) < str2.at(i);
+            auto str1n = numberStr(name1, it1 - name1.constBegin()).toUInt();
+            auto str2n = numberStr(name2, it2 - name2.constBegin()).toUInt();
+            if (str1n == str2n) {
+                // 如果数值相同，全角数字排在半角数字后面
+                bool isFullWidth1 = isFullWidthChar(*it1, number1);
+                bool isFullWidth2 = isFullWidthChar(*it2, number2);
+                if (isFullWidth1 != isFullWidth2)
+                    return !isFullWidth1;
+                return unicode1 < unicode2;
+            }
             return str1n < str2n;
         }
 
-        // 判断特殊字符就排到最后
-        isSybol1 = isSymbol(str1.at(i));
-        isSybol2 = isSymbol(str2.at(i));
-        if (isSybol1 ^ isSybol2)
-            return !isSybol1;
+        // 处理特殊字符
+        QChar normalized1, normalized2;
+        bool isFullWidth1 = isFullWidthChar(*it1, normalized1);
+        bool isFullWidth2 = isFullWidthChar(*it2, normalized2);
 
-        if (isSybol1)
-            return str1.at(i) < str2.at(i);
+        isSymbol1 = !it1->isHighSurrogate() && isSymbol(*it1);
+        isSymbol2 = !it2->isHighSurrogate() && isSymbol(*it2);
+
+        // 如果都是符号，先比较归一化后的字符
+        if (isSymbol1 && isSymbol2) {
+            QChar ch1 = isFullWidth1 ? normalized1 : *it1;
+            QChar ch2 = isFullWidth2 ? normalized2 : *it2;
+            if (ch1 != ch2)
+                return ch1 < ch2;
+            // 如果归一化后相同，全角排在半角后面
+            if (isFullWidth1 != isFullWidth2)
+                return !isFullWidth1;
+            // 如果全半角属性也相同，继续比较下一个字符
+            if (it1->isHighSurrogate()) {
+                ++it1;
+                ++it2;
+            }
+            ++it1;
+            ++it2;
+            continue;
+        }
+
+        // 如果一个是符号一个不是，符号排在后面
+        if (isSymbol1 ^ isSymbol2)
+            return isSymbol2;
+
+        // 处理汉字(包括扩展汉字)
+        QChar::Script script1 = it1->isHighSurrogate() ? QChar::script(unicode1) : it1->script();
+        QChar::Script script2 = it2->isHighSurrogate() ? QChar::script(unicode2) : it2->script();
+        isHanzi1 = script1 == QChar::Script_Han;
+        isHanzi2 = script2 == QChar::Script_Han;
 
-        // 判断汉字
-        isHanzi1 = str1.at(i).script() == QChar::Script_Han;
-        isHanzi2 = str2.at(i).script() == QChar::Script_Han;
         if (isHanzi2 ^ isHanzi1)
             return !isHanzi1;
+        if (isHanzi1) {
+            // 直接使用 QString 构造包含单个 Unicode 码点的字符串
+            QString str1 = makeQString(it1, unicode1);
+            QString str2 = makeQString(it2, unicode2);
+            return sortCollator.compare(str1, str2) < 0;
+        }
 
-        if (isHanzi1)
-            return sortCollator.compare(str1.at(i), str2.at(i)) < 0;
-
-        // 判断数字或者字符
-        if (!isNumb1 && !isNumb2)
-            return str1.at(i).toLower() < str2.at(i).toLower();
+        // 处理普通字符
+        if (!isNumb1 && !isNumb2) {
+            QString str1 = makeQString(it1, unicode1);
+            QString str2 = makeQString(it2, unicode2);
+            return str1.toLower() < str2.toLower();
+        }
 
         return isNumb1;
     }
 
-    if (length1 == length2) {
-        if (suf1.isEmpty() ^ suf2.isEmpty())
-            return suf1.isEmpty();
+    // 如果前面的字符都相同，较短的字符串排在前面
+    if (it1 == name1.constEnd())
+        return true;
+    if (it2 == name2.constEnd())
+        return false;
 
-        if (suf2.startsWith(suf1) ^ suf1.startsWith(suf2))
-            return suf2.startsWith(suf1);
+    // 处理后缀
+    if (suf1.isEmpty() ^ suf2.isEmpty())
+        return suf1.isEmpty();
 
-        return suf1 < suf2;
-    }
+    if (suf2.startsWith(suf1) ^ suf1.startsWith(suf2))
+        return suf2.startsWith(suf1);
 
-    return length1 < length2;
+    return suf1 < suf2;
 }
 
 bool FileUtils::compareString(const QString &str1, const QString &str2, Qt::SortOrder order)
@@ -1273,7 +1390,7 @@ QString FileUtils::nonExistFileName(FileInfoPointer fromInfo, FileInfoPointer ta
     QString fileBaseName = fromInfo->nameOf(NameInfoType::kCompleteBaseName);
     QString suffix = fromInfo->nameOf(NameInfoType::kSuffix);
     QString fileName = fromInfo->nameOf(NameInfoType::kFileName);
-    //在7z分卷压缩后的名称特殊处理7z.003
+    // 在7z分卷压缩后的名称特殊处理7z.003
     const QString &reg = ".7z.[0-9]{3,10}$";
     if (fileName.contains(QRegularExpression(reg))) {
         const int &index = fileName.indexOf(QRegularExpression(reg));
@@ -1318,25 +1435,18 @@ int FileUtils::dirFfileCount(const QUrl &url)
 bool FileUtils::fileCanTrash(const QUrl &url)
 {
     // gio does not support root user to move ordinary user files to trash
-    auto info = InfoFactory::create<FileInfo>(url);
-    if (SysInfoUtils::isRootUser()) {
-        int ownerId = info.isNull() ? -1 : info->extendAttributes(FileInfo::FileExtendedInfoType::kOwnerId).toInt();
-        if (ownerId != 0)
-            return false;
-    }
-
-    // 获取当前配置
-    bool alltotrash = DConfigManager::instance()->value(kDefaultCfgPath, kFileAllTrash).toBool();
-    if (!alltotrash)
-        return info ? info->extendAttributes(ExtInfoType::kFileLocalDevice).toBool() : isLocalDevice(url);
-    if (!url.isValid())
+    auto info = InfoFactory::create<FileInfo>(url, Global::CreateFileInfoType::kCreateFileInfoSync);
+    if (!info)
         return false;
 
-    const QString &path = url.toLocalFile();
-    static const QString gvfsMatch { "(^/run/user/\\d+/gvfs/|^/root/.gvfs/)" };
-    QRegularExpression re { gvfsMatch };
-    QRegularExpressionMatch match { re.match(path) };
-    return !match.hasMatch();
+    if (SysInfoUtils::isRootUser())
+        return info->canAttributes(CanableInfoType::kCanTrash);
+
+    bool alltotrash = DConfigManager::instance()->value(kDefaultCfgPath, kFileAllTrash).toBool();
+    if (alltotrash)
+        return info->canAttributes(CanableInfoType::kCanTrash);
+
+    return ProtocolUtils::isLocalFile(url) && info->canAttributes(CanableInfoType::kCanTrash);
 }
 
 QUrl FileUtils::bindUrlTransform(const QUrl &url)
@@ -1402,8 +1512,8 @@ QUrl DesktopAppUrl::homeDesktopFileUrl()
 }
 
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-///###: Do not modify it.
-///###: it's auxiliary.
+/// ###: Do not modify it.
+/// ###: it's auxiliary.
 float codecConfidenceForData(const QTextCodec *codec, const QByteArray &data, const QLocale::Country &country)
 {
     qreal hepCount = 0;
@@ -1555,4 +1665,32 @@ bool Match::match(const QString &path, const QString &name)
     return false;
 }
 
+QString FileUtils::findIconFromXdg(const QString &iconName)
+{
+    // NOTE: qtxdg-dev-tools only Qt5 supported now!
+    if (!QStandardPaths::findExecutable("qtxdg-iconfinder").isEmpty()) {
+        QProcess process;
+        process.start("qtxdg-iconfinder", QStringList() << iconName);
+        process.closeWriteChannel();
+        process.waitForFinished();
+
+        QString outputTxt = process.readAllStandardOutput();
+        QStringList list = outputTxt.split("\n");
+
+        if (list.size() > 3) {
+            // Remove unnecessary lines
+            list.removeFirst();
+            list.removeLast();
+            list.removeLast();
+
+            return list.first().simplified();
+        }
+
+        return QString();
+    } else {
+        qCWarning(logDFMBase) << "qtxdg-iconfinder not found";
+        return QString();
+    }
+}
+
 }
