@@ -24,19 +24,11 @@
 #include <QRegularExpression>
 #include <DUtil>
 
-#ifdef COMPILE_ON_V23
-#    define APP_MANAGER_SERVICE "org.desktopspec.ApplicationManager1"
-#    define APP_MANAGER_PATH_PREFIX "/org/desktopspec/ApplicationManager1"
-#    define APP_INTERFACE "org.desktopspec.ApplicationManager1.Application"
-
+#ifdef COMPILE_ON_V2X
 #    define SYSTEM_SYSTEMINFO_SERVICE "org.deepin.dde.SystemInfo1"
 #    define SYSTEM_SYSTEMINFO_PATH "/org/deepin/dde/SystemInfo1"
 #    define SYSTEM_SYSTEMINFO_INTERFACE "org.deepin.dde.SystemInfo1"
 
-#    define DEAMON_SYSTEMINFO_SERVICE "org.deepin.daemon.SystemInfo1"
-#    define DEAMON_SYSTEMINFO_PATH "/org/deepin/daemon/SystemInfo1"
-#    define DEAMON_SYSTEMINFO_INTERFACE "org.deepin.daemon.SystemInfo1"
-
 #    define DEAMON_DOCK_SERVICE "org.deepin.dde.daemon.Dock1"
 #    define DEAMON_DOCK_PATH "/org/deepin/dde/daemon/Dock1"
 #    define DEAMON_DOCK_INTERFACE "org.deepin.dde.daemon.Dock1"
@@ -183,7 +175,7 @@ void UniversalUtils::blockShutdown(QDBusReply<QDBusUnixFileDescriptor> &replay)
                                 QDBusConnection::systemBus());
 
     QList<QVariant> arg;
-    arg << QString("shutdown:sleep:")   // what
+    arg << QString("shutdown:sleep")   // what
         << qApp->applicationDisplayName()   // who
         << QObject::tr("Files are being processed")   // why
         << QString("block");   // mode
@@ -209,9 +201,9 @@ qint64 UniversalUtils::computerMemory()
 
 void UniversalUtils::computerInformation(QString &cpuinfo, QString &systemType, QString &edition, QString &version)
 {
-    QDBusInterface systemInfo(DEAMON_SYSTEMINFO_SERVICE,
-                              DEAMON_SYSTEMINFO_PATH,
-                              DEAMON_SYSTEMINFO_INTERFACE,
+    QDBusInterface systemInfo(SYSTEM_SYSTEMINFO_SERVICE,
+                              SYSTEM_SYSTEMINFO_PATH,
+                              SYSTEM_SYSTEMINFO_INTERFACE,
                               QDBusConnection::sessionBus());
 
     if (systemInfo.isValid()) {
@@ -261,84 +253,9 @@ QString UniversalUtils::sizeFormat(qint64 size, int percision)
     return QString("%1 %2").arg(QString::number(numberPart, 'f', percision)).arg(unit);
 }
 
-bool UniversalUtils::checkLaunchAppInterface()
-{
-    static bool initStatus = true;
-    static std::once_flag flag;
-    std::call_once(flag, []() {
-        QDBusConnectionInterface *interface = QDBusConnection::sessionBus().interface();
-        if (!interface || !interface->isServiceRegistered(APP_MANAGER_SERVICE).value()) {
-            initStatus = false;
-            return;
-        }
-#ifndef COMPILE_ON_V23
-        QDBusInterface introspect(APP_MANAGER_SERVICE,
-                                  APP_MANAGER_PATH,
-                                  "org.freedesktop.DBus.Introspectable",
-                                  QDBusConnection::sessionBus());
-        introspect.setTimeout(1000);
-        QDBusPendingReply<QString> reply = introspect.asyncCallWithArgumentList(QStringLiteral("Introspect"), {});
-        reply.waitForFinished();
-        if (reply.isFinished() && reply.isValid() && !reply.isError()) {
-            QString xmlCode = reply.argumentAt(0).toString();
-            if (xmlCode.contains(APP_MANAGER_INTERFACE)) {
-                if (xmlCode.contains("LaunchApp")) {
-                    initStatus = true;
-                } else {
-                    qCWarning(logDFMBase) << QString("%1 : doesn't have LaunchApp interface.").arg(APP_MANAGER_SERVICE);
-                    initStatus = false;
-                }
-            } else {
-                qCWarning(logDFMBase) << QString("%1 : Introspect error").arg(APP_MANAGER_SERVICE) << xmlCode;
-                initStatus = false;
-            }
-        } else {
-            initStatus = false;
-        }
-#endif
-    });
-    return initStatus;
-}
-
-bool UniversalUtils::launchAppByDBus(const QString &desktopFile, const QStringList &filePaths)
-{
-#ifdef COMPILE_ON_V23
-    const auto &file = QFileInfo { desktopFile };
-    constexpr auto kDesktopSuffix { u8"desktop" };
-
-    if (file.suffix() != kDesktopSuffix) {
-        qCDebug(logDFMBase) << "invalid desktop file:" << desktopFile << file;
-        return false;
-    }
-
-    const auto &DBusAppId = DUtil::escapeToObjectPath(file.completeBaseName());
-    const auto &currentAppPath = QString { APP_MANAGER_PATH_PREFIX } + "/" + DBusAppId;
-    qCDebug(logDFMBase) << "app object path:" << currentAppPath;
-    QDBusInterface appManager(APP_MANAGER_SERVICE,
-                              currentAppPath,
-                              APP_INTERFACE,
-                              QDBusConnection::sessionBus());
-
-    auto reply = appManager.callWithArgumentList(QDBus::Block, QStringLiteral("Launch"), { QVariant::fromValue(QString {}), QVariant::fromValue(filePaths), QVariant::fromValue(QVariantMap {}) });
-
-    return reply.type() == QDBusMessage::ReplyMessage;
-
-#else
-    QDBusInterface appManager(APP_MANAGER_SERVICE,
-                              APP_MANAGER_PATH,
-                              APP_MANAGER_INTERFACE,
-                              QDBusConnection::sessionBus());
-
-    QList<QVariant> argumentList;
-    argumentList << QVariant::fromValue(desktopFile) << QVariant::fromValue(static_cast<uint>(QX11Info::getTimestamp())) << QVariant::fromValue(filePaths);
-    appManager.asyncCallWithArgumentList(QStringLiteral("LaunchApp"), argumentList);
-    return true;
-#endif
-}
-
 bool UniversalUtils::runCommand(const QString &cmd, const QStringList &args, const QString &wd)
 {
-#ifdef COMPILE_ON_V23
+#ifdef COMPILE_ON_V2X
     qCDebug(logDFMBase) << "new AM wouldn't provide any method to run Command, so launch cmd by qt:" << cmd << args;
     return QProcess::startDetached(cmd, args, wd);
 #else
@@ -581,4 +498,22 @@ void UniversalUtils::boardCastPastData(const QUrl &sourcPath, const QUrl &target
     fileMonitor.asyncCallWithArgumentList(QStringLiteral("PrepareSendData"), data);
 }
 
+int UniversalUtils::getTextLineHeight(const QModelIndex &index, const QFontMetrics &fontMetrics)
+{
+    auto text = index.data(Global::ItemRoles::kItemFileDisplayNameRole).toString();
+    return getTextLineHeight(text, fontMetrics);
+}
+
+int UniversalUtils::getTextLineHeight(const QString &text, const QFontMetrics &fontMetrics)
+{
+    if (text.isEmpty())
+        return fontMetrics.height();
+
+    auto textRect = fontMetrics.boundingRect(text);
+    if (textRect.height() <= 0)
+        return fontMetrics.height();
+
+    return textRect.height();
+}
+
 }
