@@ -25,8 +25,11 @@ public:
     static bool keyCtrlIsPressed();
 
     static bool keyAltIsPressed();
+
     static QScreen *cursorScreen();
+
+    static void closeAllFileManagerWindows();
 };
 
-}
+}   // namespace dfmbase
 #endif   // WINDOWUTILS_H
