@@ -47,7 +47,6 @@ DFMBASE_USE_NAMESPACE
 namespace ConstDef {
 static constexpr int kKeyWidth { 80 };
 static constexpr int kWidgetFixedWidth { 195 };
-static constexpr char kShareNameRegx[] { "^[^\\[\\]\"'/\\\\:|<>+=;,?*\r\n\t]*$" };
 static constexpr char kShareFileDir[] { "/var/lib/samba/usershares" };
 }
 
@@ -179,20 +178,13 @@ void ShareControlWidget::setupShareSwitcher()
 
 void ShareControlWidget::setupShareNameEditor()
 {
-    shareNameEditor = new QLineEdit(this);
+    shareNameEditor = new DLineEdit(this);
 
-    QValidator *validator = new QRegularExpressionValidator(QRegularExpression(ConstDef::kShareNameRegx), this);
-    shareNameEditor->setValidator(validator);
+    static constexpr char kShareNameRegx[] { R"(^(?![ -])[^%<>*?|/\\+=;:,"]*+ ?$)" };
+    QValidator *validator = new QRegularExpressionValidator(QRegularExpression(kShareNameRegx), this);
+    shareNameEditor->lineEdit()->setValidator(validator);
 
-    connect(shareNameEditor, &QLineEdit::textChanged, this, [=](const QString &text) {
-        QString newText(text);
-        // daemon create the mountpoint of share: <name> on <host>, which occupied 255 bytes at most.
-        // and only 255 - 20 bytes for share name.
-        // the max length of folder name limited to 255 bytes in nativa file system.
-        while (newText.toLocal8Bit().length() > (NAME_MAX - 20))
-            newText.chop(1);
-        shareNameEditor->setText(newText);
-    });
+    connect(shareNameEditor, &DLineEdit::textChanged, this, &ShareControlWidget::onShareNameChanged);
 }
 
 void ShareControlWidget::setupSharePermissionSelector()
@@ -241,12 +233,13 @@ QHBoxLayout *ShareControlWidget::setupNetworkPath()
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
             this, setBtnIcon);
     setBtnIcon();
-    QObject::connect(copyNetAddr, &QPushButton::clicked, [=]() {
+    QObject::connect(copyNetAddr, &QPushButton::clicked, this, [=]() {
         QClipboard *clipboard = QApplication::clipboard();
         clipboard->setText(netScheme->text() + networkAddrLabel->text());
     });
 
     QHBoxLayout *hBoxLine = new QHBoxLayout(this);
+    hBoxLine->setSpacing(0);
     hBoxLine->setContentsMargins(0, 0, 2, 0);
     hBoxLine->addWidget(netScheme);
     hBoxLine->addWidget(networkAddrLabel);
@@ -274,7 +267,7 @@ QHBoxLayout *ShareControlWidget::setupUserName()
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
             this, setBtnIcon);
     setBtnIcon();
-    QObject::connect(copyUserNameBt, &QPushButton::clicked, [=]() {
+    QObject::connect(copyUserNameBt, &QPushButton::clicked, this, [this]() {
         QClipboard *clipboard = QApplication::clipboard();
         clipboard->setText(userNamelineLabel->text());
     });
@@ -302,7 +295,7 @@ QHBoxLayout *ShareControlWidget::setupSharePassword()
     setPasswordBt->setText(isSharePasswordSet ? tr("Change password") : tr("Set password"));
     setPasswordBt->setContentsMargins(0, 0, 0, 0);
     setPasswordBt->setToolTip(setPasswordBt->text());
-    QObject::connect(setPasswordBt, &QPushButton::clicked, [this]() {
+    QObject::connect(setPasswordBt, &QPushButton::clicked, this, [this]() {
         showSharePasswordSettingsDialog();
     });
 
@@ -383,7 +376,7 @@ void ShareControlWidget::initConnection()
 
     connect(shareAnonymousSelector, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ShareControlWidget::updateShare);
     connect(sharePermissionSelector, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ShareControlWidget::updateShare);
-    connect(shareNameEditor, &QLineEdit::editingFinished, this, &ShareControlWidget::updateShare);
+    connect(shareNameEditor, &DLineEdit::editingFinished, this, &ShareControlWidget::updateShare);
     connect(UserShareHelper::instance(), &UserShareHelper::sambaPasswordSet, this, &ShareControlWidget::onSambaPasswordSet);
 
     dpfSignalDispatcher->subscribe("dfmplugin_dirshare", "signal_Share_ShareAdded", this, &ShareControlWidget::updateWidgetStatus);
@@ -447,12 +440,6 @@ bool ShareControlWidget::validateShareName()
             }
 
             if (dlg.exec() != DDialog::Accepted) {
-                if (isShared) {
-                    QString filePath = url.path();
-                    auto shareName = UserShareHelperInstance->shareNameByPath(filePath);
-                    shareNameEditor->setText(shareName);
-                    shareSwitcher->setChecked(isShared);
-                }
                 shareNameEditor->setFocus();
                 return false;
             }
@@ -465,25 +452,23 @@ bool ShareControlWidget::validateShareName()
 
 void ShareControlWidget::updateShare()
 {
-    if (!isUpdating)
-        shareFolder();
-    return;
+    if (!shareFolder() && !UserShareHelperInstance->isShared(url.path())) {
+        shareSwitcher->setChecked(false);
+        sharePermissionSelector->setEnabled(false);
+        shareAnonymousSelector->setEnabled(false);
+    }
 }
 
-void ShareControlWidget::shareFolder()
+bool ShareControlWidget::shareFolder()
 {
-    bool isShared = UserShareHelperInstance->isShared(url.path());
-    if (!shareSwitcher->isChecked())
-        return;
-    isUpdating = true;
+    if (!shareSwitcher->isChecked()) {
+        fmWarning() << "Share Folder failed, error check state";
+        return false;
+    }
+
     if (!validateShareName()) {
-        if (!isShared) {
-            shareSwitcher->setChecked(false);
-            sharePermissionSelector->setEnabled(false);
-            shareAnonymousSelector->setEnabled(false);
-        }
-        isUpdating = false;
-        return;
+        fmWarning() << "Share Folder failed, error folder name";
+        return false;
     }
 
     bool writable = sharePermissionSelector->currentIndex() == 0;
@@ -521,17 +506,19 @@ void ShareControlWidget::shareFolder()
         { ShareInfoKeys::kAnonymous, anonymous }
     };
     bool success = UserShareHelperInstance->share(info);
-    if (!success) {
-        shareSwitcher->setChecked(false);
-        sharePermissionSelector->setEnabled(false);
-        shareAnonymousSelector->setEnabled(false);
-    }
-    isUpdating = false;
+    if (!success)
+        fmWarning() << "share folder failed";
+    return success;
 }
 
-void ShareControlWidget::unshareFolder()
+bool ShareControlWidget::unshareFolder()
 {
-    UserShareHelperInstance->removeShareByPath(url.path());
+    if (shareSwitcher->isChecked()) {
+        fmWarning() << "Unshare Folder failed, error check state";
+        return false;
+    }
+
+    return UserShareHelperInstance->removeShareByPath(url.path());
 }
 
 void ShareControlWidget::updateWidgetStatus(const QString &filePath)
@@ -579,6 +566,9 @@ void ShareControlWidget::updateFile(const QUrl &oldOne, const QUrl &newOne)
 void ShareControlWidget::onSambaPasswordSet(bool result)
 {
     isSharePasswordSet = result;
+    // BUG: 304479
+    if (shareSwitcher && isSharePasswordSet && !shareSwitcher->isChecked())
+        shareSwitcher->click();
 
     QFont font = sharePassword->font();
     int defaultFontSize = font.pointSize();
@@ -589,6 +579,22 @@ void ShareControlWidget::onSambaPasswordSet(bool result)
     setPasswordBt->setText(isSharePasswordSet ? tr("Change password") : tr("Set password"));
 }
 
+void ShareControlWidget::onShareNameChanged(const QString &name)
+{
+    static const int kShareNameMaxLen { 150 };
+    QString newText(name.trimmed());
+    bool showAlert = false;
+    while (newText.toLocal8Bit().length() > kShareNameMaxLen) {
+        newText.chop(1);
+        showAlert = true;
+    }
+    shareNameEditor->setText(newText);
+    QTimer::singleShot(0, shareNameEditor, [this, showAlert] {
+        if (showAlert)
+            shareNameEditor->showAlertMessage(tr("The shared name is too long and will be truncated."));
+    });
+}
+
 void ShareControlWidget::showMoreInfo(bool showMore)
 {
     moreInfoFrame->setHidden(!showMore);
@@ -603,18 +609,28 @@ void ShareControlWidget::showMoreInfo(bool showMore)
 
 void ShareControlWidget::userShareOperation(bool checked)
 {
-    if (!isSharePasswordSet && checked)
-        showSharePasswordSettingsDialog();
+    if (shareNameEditor->text().trimmed().isEmpty())
+        shareNameEditor->setText(info->displayOf(DisPlayInfoType::kFileDisplayName));
+
+    bool success { false };
+    if (checked) {
+        if (isSharePasswordSet)
+            success = shareFolder();
+        else
+            showSharePasswordSettingsDialog();
+    } else {
+        success = unshareFolder();
+    }
+
+    if (success) {
+        sharePermissionSelector->setEnabled(checked);
+        shareAnonymousSelector->setEnabled(checked);
+    } else {
+        shareSwitcher->setChecked(!checked);
+    }
 
-    sharePermissionSelector->setEnabled(checked);
-    shareAnonymousSelector->setEnabled(checked);
     shareSwitcher->setEnabled(false);
     timer->start();
-    if (checked)
-        this->shareFolder();
-    else
-        this->unshareFolder();
-
     showMoreInfo(checked);
 }
 
@@ -626,13 +642,13 @@ void ShareControlWidget::showSharePasswordSettingsDialog()
     dialog->show();
     dialog->moveToCenter();
     dialog->setAttribute(Qt::WA_DeleteOnClose);
-    QObject::connect(dialog, &UserSharePasswordSettingDialog::finished, dialog, &UserSharePasswordSettingDialog::onButtonClicked);
+    QObject::connect(dialog, &UserSharePasswordSettingDialog::buttonClicked, dialog, &UserSharePasswordSettingDialog::onButtonClicked);
     this->setProperty("UserSharePwdSettingDialogShown", true);
     QObject::connect(dialog, &UserSharePasswordSettingDialog::inputPassword, [=](const QString &password) {
         QString userName = UserShareHelperInstance->currentUserName();
         UserShareHelperInstance->setSambaPasswd(userName, password);
     });
-    QObject::connect(dialog, &UserSharePasswordSettingDialog::closed, [=] {
+    QObject::connect(dialog, &UserSharePasswordSettingDialog::closed, this, [this] {
         this->setProperty("UserSharePwdSettingDialogShown", false);
     });
 }
