@@ -18,6 +18,7 @@
 #include <dfm-base/dfm_event_defines.h>
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/utils/iconutils.h>
+#include <dfm-base/utils/universalutils.h>
 
 #include <dfm-framework/dpf.h>
 
@@ -65,8 +66,9 @@ ElideTextLayout *CollectionItemDelegatePrivate::createTextlayout(const QModelInd
     QString name = showSuffix ? index.data(Global::ItemRoles::kItemFileDisplayNameRole).toString()
                               : index.data(Global::ItemRoles::kItemFileBaseNameOfRenameRole).toString();
     ElideTextLayout *layout = new ElideTextLayout(name);
+    int lineHeight = UniversalUtils::getTextLineHeight(index, q->parent()->fontMetrics());
     layout->setAttribute(ElideTextLayout::kWrapMode, (uint)QTextOption::WrapAtWordBoundaryOrAnywhere);
-    layout->setAttribute(ElideTextLayout::kLineHeight, textLineHeight);
+    layout->setAttribute(ElideTextLayout::kLineHeight, lineHeight);
     layout->setAttribute(ElideTextLayout::kAlignment, Qt::AlignHCenter);
     if (painter) {
         layout->setAttribute(ElideTextLayout::kFont, painter->font());
@@ -527,7 +529,9 @@ QPixmap CollectionItemDelegate::getIconPixmap(const QIcon &icon, const QSize &si
     if (size.width() <= 0 || size.height() <= 0)
         return QPixmap();
 
-    auto px = icon.pixmap(size, mode, state);
+    // 根据设备像素比获取合适大小的pixmap
+    QSize deviceSize = size * pixelRatio;
+    auto px = icon.pixmap(deviceSize, mode, state);
     px.setDevicePixelRatio(pixelRatio);
 
     return px;
@@ -766,10 +770,21 @@ QRect CollectionItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, co
     Qt::Alignment alignment { visualAlignment(painter->layoutDirection(), opts.alignment) };
     const qreal pixelRatio = painter->device()->devicePixelRatioF();
     const QPixmap &px = getIconPixmap(icon, opts.rect.size().toSize(), pixelRatio, opts.mode, opts.state);
-    qreal x = opts.rect.x();
-    qreal y = opts.rect.y();
+
+    // 保持图标原始比例
     qreal w = px.width() / px.devicePixelRatio();
     qreal h = px.height() / px.devicePixelRatio();
+
+    // 如果图标大于目标区域，等比例缩放
+    if (w > opts.rect.width() || h > opts.rect.height()) {
+        qreal scale = qMin(opts.rect.width() / w, opts.rect.height() / h);
+        w *= scale;
+        h *= scale;
+    }
+
+    qreal x = opts.rect.x();
+    qreal y = opts.rect.y();
+
     if ((alignment & Qt::AlignVCenter) == Qt::AlignVCenter)
         y += (opts.rect.size().height() - h) / 2.0;
     else if ((alignment & Qt::AlignBottom) == Qt::AlignBottom)
@@ -805,10 +820,11 @@ QRect CollectionItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, co
         return backgroundRect;
     }
 
-    icon.paint(painter, opts.rect.toRect());
+    // 使用QRectF和drawPixmap的重载版本来正确处理缩放
+    QRect targetRect(x, y, w, h);
+    painter->drawPixmap(targetRect, px, px.rect());
 
-    // return rect before scale
-    return QRect(qRound(x), qRound(y), w, h);
+    return targetRect;
 }
 
 QRectF CollectionItemDelegate::paintEmblems(QPainter *painter, const QRectF &rect, const FileInfoPointer &info)
