@@ -466,7 +466,7 @@ bool NormalizedMode::initialize(CollectionModel *m)
 
     // sync selection
     d->selectionHelper->setInnerModel(d->selectionModel);
-    //d->selectionHelper->setExternalModel(canvasSelectionShell->selectionModel());
+    d->selectionHelper->setExternalModel(canvasSelectionShell->selectionModel());
     d->selectionHelper->setShell(canvasSelectionShell);
     d->selectionHelper->setEnabled(true);
 
@@ -678,9 +678,9 @@ void NormalizedMode::rebuild(bool reorganize)
     QElapsedTimer time;
     time.start();
     {
+        if (reorganize && d->classifier->updateClassifier())  // classifier's categories should be updated.
+            model->refresh(model->rootIndex(), false, 0);
         auto files = model->files();
-        if (reorganize)   // classifier's categories should be updated.
-            d->classifier->updateClassifier();
         d->classifier->reset(files);
 
         // order item as config
