@@ -34,6 +34,11 @@ signals:
     void matched(const QString &taskId);
     void searchCompleted(const QString &taskId);
     void searchStoped(const QString &taskId);
+    void enableFullTextSearchChanged(bool enable);
+
+    void fileAdd(const QUrl &url);
+    void fileDelete(const QUrl &url);
+    void fileRename(const QUrl &oldUrl, const QUrl &newUrl);
 
 private:
     explicit SearchManager(QObject *parent = nullptr);
