@@ -31,11 +31,6 @@ void VaultEventCaller::sendVaultProperty(const QUrl &url)
     dpfSlotChannel->push("dfmplugin_propertydialog", "slot_PropertyDialog_Show", QList<QUrl>() << url, QVariantHash());
 }
 
-void VaultEventCaller::sendBookMarkDisabled(const QString scheme)
-{
-    dpfSlotChannel->push("dfmplugin_bookmark", "slot_Scheme_Disable", scheme);
-}
-
 void VaultEventCaller::sendOpenFiles(const quint64 windowID, const QList<QUrl> &urls)
 {
     dpfSignalDispatcher->publish(GlobalEventType::kOpenFiles, windowID, urls);
