@@ -19,14 +19,20 @@ class VaultActiveFinishedView;
 class VaultActiveSaveKeyFileView;
 class VaultActiveView : public VaultPageBase
 {
+    Q_OBJECT
 public:
     explicit VaultActiveView(QWidget *parent = nullptr);
 
 private slots:
     void slotNextWidget();
+    void encryptVault();
 
 private:
     void setBeginingState();
+    void asyncCreateVault();
+    Result createVault();
+    bool handleKeyModeEncryption();
+    bool handleTransparentModeEncryption();
 
 private:
     //! 窗口容器
@@ -36,6 +42,8 @@ private:
     VaultActiveSetUnlockMethodView *setUnclockMethodWidget { nullptr };
     VaultActiveFinishedView *activeVaultFinishedWidget { nullptr };
     VaultActiveSaveKeyFileView *saveKeyFileWidget { nullptr };
+
+    EncryptInfo encryptInfo;
 };
 }
 #endif   //! VAULTACTIVEVIEW_H
